*Remittances analysis for the Somali Poverty Profile 2016

set more off
set seed 23081980 
set sortseed 11041955

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Introduce the regional breakdown to be used for the poverty assessment
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen ind_profile=6 if astrata==3
replace ind_profile=5 if astrata==22
replace ind_profile=4 if astrata==21
replace ind_profile=3 if astrata==14 | astrata==15
replace ind_profile=2 if astrata==12 | astrata==13 
replace ind_profile=1 if astrata==11
label define lind_profile 1 "Mogadishu (Urban)" 2 "North-east Urban (Nugaal,Bari,Mudug)" 3 "North-west Urban (Woqooyi G,Awdal,Sanaag,Sool,Togdheer)" 4 "North-east Rural (Bari,Mudug,Nugaal)" 5 "North-west Rural (Awdal,Sanaag,Sool,Togdheer,Woqooyi)" 6 "IDP Settlements"
label values ind_profile lind_profile
label var ind_profile "Indicator: Mogadishu, North-East urban/rural, North-West urban/rural & IDPs"
keep astrata strata ea block hh ind_profile
save "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", replace



*************************************
***         Remittances           ***
*************************************

*Prepare the data 
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"

*Poverty between recievers and non-recievers of remittances
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean poorPPP se) f(3) sebnone npos(col) h2(Poverty & remittances) replace

*Remittances (by urban/rural status, hhh gender, hhh education, poverty status and quintile)
qui foreach var of varlist ind_profile hhh_gender hhh_edu poorPPP quintiles_tc {
	tabout remit12m `var' using "${gsdOutput}/Raw_Data_1.xls", svy percent c(col se) sebnone npos(col) h1(Remittances by `var') append
}

*Mean socioeconomic characteristics between recievers and non-recievers of remittances
qui foreach var of varlist hhh_age pdependent penrol pgender pliteracy  {
	tabout remit12m using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean `var' se) h2(Mean `var' between recievers and non-recievers of remittances)  f(3) sebnone npos(col) append 
}

*Test the difference in means for various groups
* hhh gender
svy: mean remit12m, over(hhh_gender)
lincom [remit12m]Female - [remit12m]Male
svy: mean remit12m_pc, over(hhh_gender)
lincom [remit12m_pc]Female - [remit12m_pc]Male
* educational statistics
gen edu = !(hhh_edu==0) if !mi(hhh_edu)
svy: mean remit12m, over(edu)
lincom [remit12m]0 - [remit12m]1
svy: mean remit12m_pc, over(edu)
lincom [remit12m_pc]0 - [remit12m_pc]1

foreach var of varlist hhh_age pdependent penrol pgender pliteracy hhsize {
	svy: mean `var', over(remit12m)
	lincom [`var']Yes - [`var']No
}

*Conditional USD value of remittances per capita (by urban/rural status, hhh gender, hhh education, poverty status and quintile)
qui foreach var of varlist ind_profile hhh_gender hhh_edu poorPPP quintiles_tc {
	tabout `var' using "${gsdOutput}/Raw_Data_1.xls" if !missing(remit12m_pc), svy sum c(mean remit12m_pc se) f(3) sebnone npos(col) h2(Mean value (USD) of remittances pc (Conditional), last 12m by `var') append
}

*Unconditional USD value of remittances per capita (by urban/rural status, hhh gender, hhh education, poverty status and quintile)
recode remit12m_pc (.=0)
qui foreach var of varlist ind_profile hhh_gender hhh_edu poorPPP quintiles_tc {
	tabout `var' using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean remit12m_pc se) f(3) sebnone npos(col) h2(Mean value (USD) of remittances pc (Unconditional), last 12m by `var') append
}

*Mean imputed consumption between recievers and non-recievers of remittances (by urban/rural status)
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==1, svy sum c(mean tc_imp se) h2(Mean tc_imp between recievers and non-recievers of remittances in 1)  f(3) sebnone npos(col) append 
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==2, svy sum c(mean tc_imp se) h2(Mean tc_imp between recievers and non-recievers of remittances in 2)  f(3) sebnone npos(col) append 
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==3, svy sum c(mean tc_imp se) h2(Mean tc_imp between recievers and non-recievers of remittances in 3)  f(3) sebnone npos(col) append 
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==4, svy sum c(mean tc_imp se) h2(Mean tc_imp between recievers and non-recievers of remittances in 4)  f(3) sebnone npos(col) append 
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==5, svy sum c(mean tc_imp se) h2(Mean tc_imp between recievers and non-recievers of remittances in 5)  f(3) sebnone npos(col) append 
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==6, svy sum c(mean tc_imp se) h2(Mean tc_imp between recievers and non-recievers of remittances in 6)  f(3) sebnone npos(col) append 

*Hours worked
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(type hhh_gender quintiles_tc weight_cons poorPPP remit12m) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout emp_hrs_cat remit12m using "${gsdOutput}/Raw_Data_1.xls", svy percent c(col se) npos(col) sebnone h2(Hours worked by status) append

* Household head gender by receiving status
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 astrata using "${gsdData}/1-CleanTemp/food-deflator.dta", nogen assert(match) keep(match) keepusing(deflator)
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
qui tabout hhh_gender remit12m  using "${gsdOutput}/Raw_Data_1.xls", svy percent c(col se) sebnone npos(row) h1(Remittances by hhh_gender) append

*Poverty between receivers and non-receivers (by status)
tabout remit12m ind_profile using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean poorPPP se) f(3) sebnone npos(col) h1(Poverty & remittances, by status) append

*Consumption between receivers and non-receivers (by status)
qui tabout remit12m ind_profile using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean tc_imp se) f(3) sebnone npos(col) h1(Consumption & remittances, by status) append

*Labor force participation, and hours worked (overall) between receivers and non-receivers and unemployment by region 
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(astrata hhh_gender quintiles_tc weight_cons poorPPP remit12m remit12m_usd type) nogen
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if working_age==1, svy percent c(col se) npos(col) sebnone h1(Labor force participation by remittances) append
qui tabout remit12m using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean emp_hrs se) f(3) sebnone npos(col) h1(Hours worked & remittances, by status) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemployment by remittances) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==1 & lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemploymnet by remittances ind=1) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==2  & lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemploymnet by remittances ind=2) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==3 & lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemploymnet by remittances ind=3) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==4 & lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemploymnet by remittances ind=4) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==5 & lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemploymnet by remittances ind=5) append
qui tabout unemp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==6 & lfp_7d==1, svy percent c(col se) npos(col) sebnone h1(Unemploymnet by remittances ind=6) append

*Test the difference in means for unemployment between receivers and non for each region
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
forval i=1/6 {
	svy: mean unemp_7d if ind_profile==`i', over( remit12m )
	test [unemp_7d]No = [unemp_7d]Yes
}

*Test the difference in means for labor force participation, unemployment and hrs worked
svy: mean lfp_7d, over( remit12m )
test [lfp_7d]No = [lfp_7d]Yes
svy: mean emp_hrs, over( remit12m )
test [emp_hrs]No = [emp_hrs]Yes
svy: mean unemp_7d, over( remit12m )
test [unemp_7d]No = [unemp_7d]Yes

*Correlation between hours worked & value of remittances received
merge m:1 astrata using "${gsdData}/1-CleanTemp/food-deflator.dta", nogen assert(match) keep(match) keepusing(deflator)
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
gen remit12m_pc = remit12m_usd / hhsize / deflator
la var remit12m_pc "Value of remittances pc, last 12m"
correl remit12m_pc emp_hrs [aweight=weight_cons]

*Total value of remittances
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 astrata using "${gsdData}/1-CleanTemp/food-deflator.dta", nogen assert(match) keep(match) keepusing(deflator)
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
gen x=remit12m_usd*weight_cons
egen tot_remit12m=sum(x) 
qui tabout ind_profile using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean tot_remit12m se) npos(col) sebnone h2(Total value of annual remittances - current USD) append

*Labor force participation receivers and non-receivers for each region
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(astrata hhh_gender quintiles_tc weight_cons poorPPP remit12m remit12m_usd) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls", svy percent c(col) npos(col) sebnone h1(LFP by remittances) append
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==1 , svy percent c(col) npos(col) sebnone h1(LFP by remittances ind=1) append
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==2 , svy percent c(col) npos(col) sebnone h1(LFP by remittances ind=2) append
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==3 , svy percent c(col) npos(col) sebnone h1(LFP by remittances ind=3) append
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==4 , svy percent c(col) npos(col) sebnone h1(LFP by remittances ind=4) append
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==5 , svy percent c(col) npos(col) sebnone h1(LFP by remittances ind=5) append
qui tabout lfp_7d remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==6 , svy percent c(col) npos(col) sebnone h1(LFP by remittances ind=6) append

*Test the difference in means for unemployment between receivers and non for each region
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
forval i=1/6 {
	svy: mean lfp_7d if ind_profile==`i' & lfp_7d==1, over( remit12m )
	test [lfp_7d]No = [lfp_7d]Yes
}

*Population in households that receive remittances 
qui tabout ind_profile if remit12m==1 using "${gsdOutput}/Raw_Data_1.xls", svy c(freq se) pop  sebnone npos(col) h1(Remittances by `var') append

*Enrolment rate between receivers and non-receivers for each region
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(type astrata hhh_gender quintiles_tc weight_cons poorPPP remit12m remit12m_usd) nogen
svyset ea [pweight=weight_cons], strata(strata)
gen enrolled = edu_status==1 & inrange(age, 6, 17)
label values enrolled yesno 
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls", svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=1) append
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==1 & inrange(age, 6,17), svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=1) append
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==2 & inrange(age, 6,17), svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=2) append
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==3 & inrange(age, 6,17), svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=3) append
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==4 & inrange(age, 6,17), svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=4) append
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==5 & inrange(age, 6,17), svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=5) append
qui tabout enrolled  remit12m using "${gsdOutput}/Raw_Data_1.xls" if ind_profile==6 & inrange(age, 6,17), svy percent c(col) npos(col) sebnone h1(Enrolment rate by remittances ind=6) append

*Test the difference in means for enrolment between receivers and non for each region
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean enrolled if inrange(age, 6,17), over(remit12m)
forval i=1/6 {
	svy: mean enrolled if ind_profile==`i', over( remit12m )
	test [enrolled]No = [enrolled]Yes
}

svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
* Obtain percentage of males in HH
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(hhh_id)
gen hhh = (hhh_id == hhmid)
gen pmale15 = (gender==1 & inrange(age,15,64)) if !mi(age) & hhh==0
gen pmale25 = (gender==1 & inrange(age,25,64)) if !mi(age) & hhh==0
gen sage = inrange(age, 6, 17) if !mi(age)
gen sage_m = inrange(age, 6, 17) if !mi(age) & gender==1
gen sage_f = inrange(age, 6, 17) if !mi(age) & gender==0
gen enrolled = edu_status==1 & inrange(age, 6, 17)
gen adult_literacy = literacy if age>24
collapse (mean) pmale* adult_literacy (sum) sage enrolled, by(strata ea block hh)
save "${gsdData}/1-CleanTemp/hhm_pmale.dta", replace

use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhm_pmale.dta", assert(match) nogen keepusing(pmale15 pmale25 adult_literacy)
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)
*Remittances (by urban/rural status)
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)
tabout remit12m type using "${gsdOutput}/Raw_Data_1.xls", svy percent c(col se) sebnone npos(col) h1(Remittances by Urban-rural-IDP) append
svyset ea [pweight=pweight], strata(strata) singleunit(centered)
tabout type using "${gsdOutput}/Raw_Data_1.xls" if !missing(remit12m_pc), svy sum c(mean remit12m_pc se) f(3) sebnone npos(col) h2(Mean value (USD) of remittances pc (Conditional), last 12m by rural-urban-idp) append

* Educational outcomes by remittances status and income quintile
* Enrollment in HH
tabout quintiles_tc using "${gsdOutput}/Raw_Data_1.xls" if remit12m==1, svy sum c(mean penrol se) h2(enrolment by income quintile, remit==yes)  f(3) sebnone npos(col) append 
tabout quintiles_tc using "${gsdOutput}/Raw_Data_1.xls" if remit12m==0, svy sum c(mean penrol se) h2(enrolment by income quintile, remit==no)  f(3) sebnone npos(col) append 
* check significance
svy: mean penrol if quintiles_tc==1, over(remit12m)
lincom [penrol]Yes - [penrol]No
svy: mean penrol if quintiles_tc==2, over(remit12m)
lincom [penrol]Yes - [penrol]No
svy: mean penrol if quintiles_tc==3, over(remit12m)
lincom [penrol]Yes - [penrol]No
svy: mean penrol if quintiles_tc==4, over(remit12m)
lincom [penrol]Yes - [penrol]No
svy: mean penrol if quintiles_tc==5, over(remit12m)
lincom [penrol]Yes - [penrol]No

* Literacy in HH
tabout quintiles_tc using "${gsdOutput}/Raw_Data_1.xls" if remit12m==1, svy sum c(mean adult_literacy se) h2(literacy by income quintile, remit==yes)  f(3) sebnone npos(col) append 
tabout quintiles_tc using "${gsdOutput}/Raw_Data_1.xls" if remit12m==0, svy sum c(mean adult_literacy se) h2(literacy by income quintile, remit==no)  f(3) sebnone npos(col) append 

svy: mean pliteracy if quintiles_tc==1, over(remit12m)
lincom [pliteracy]Yes - [pliteracy]No
svy: mean pliteracy if quintiles_tc==2, over(remit12m)
lincom [pliteracy]Yes - [pliteracy]No
svy: mean pliteracy if quintiles_tc==3, over(remit12m)
lincom [pliteracy]Yes - [pliteracy]No
svy: mean pliteracy if quintiles_tc==4, over(remit12m)
lincom [pliteracy]Yes - [pliteracy]No
svy: mean pliteracy if quintiles_tc==5, over(remit12m)
lincom [pliteracy]Yes - [pliteracy]No

* Remittances by HHH gender x income quintile
gen fh = (hhh_gender==0) if !mi(hhh_gender)
la val fh l_yesno
tabout quintiles_tc using "${gsdOutput}/Raw_Data_1.xls" if remit12m==1, svy sum c(mean fh se) h2(female HHH by income quintile, remit==yes)  f(3) sebnone npos(col) append 
tabout quintiles_tc using "${gsdOutput}/Raw_Data_1.xls" if remit12m==0, svy sum c(mean fh se) h2(female HHH by income quintile, remit==no)  f(3) sebnone npos(col) append 

svy: mean fh if quintiles_tc==1, over(remit12m)
lincom [fh]Yes - [fh]No
svy: mean fh if quintiles_tc==2, over(remit12m)
lincom [fh]Yes - [fh]No
svy: mean fh if quintiles_tc==3, over(remit12m)
lincom [fh]Yes - [fh]No
svy: mean fh if quintiles_tc==4, over(remit12m)
lincom [fh]Yes - [fh]No
svy: mean fh if quintiles_tc==5, over(remit12m)
lincom [fh]Yes - [fh]No


* percentage of adult males in female-headed households: recipients vs non-recipients
svy: mean pmale25, over(hhh_gender)
lincom [pmale25]Female - [pmale25]Male
svy: mean pmale25, over(hhh_gender remit12m)
lincom [pmale25]_subpop_1 - [pmale25]_subpop_2
lincom [pmale25]_subpop_3 - [pmale25]_subpop_4
gen hhh_remit = 1 if hhh_gender==1 & remit12m==1
replace hhh_remit = 2 if hhh_gender==1 & remit12m==0
replace hhh_remit = 3 if hhh_gender==0 & remit12m==1
replace hhh_remit = 4 if hhh_gender==0 & remit12m==0
la def lhhh_remit 1 "Male recipient" 2 "Male non-recipient" 3 "Female recipient" 4 "Female non-recipient", replace
la val hhh_remit lhhh_remit

tabout hhh_remit using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean pmale25 se) h2(percentage of adult (25+) males in HH)  f(3) sebnone npos(col) append 


*School expenditures 
use "${gsdData}/1-CleanOutput/nonfood.dta", clear 
merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhm_pmale.dta", assert(match using) nogen keepusing(sage)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", keep(match) keepusing(hhh_gender remit12m quintiles_tc tc_imp) nogen
keep if itemid==1080
gen cons_value = purc_usd_imp*52/sage if sage>0
la var cons_value "Mean annual educational expenses per school-aged child, current USD"
gen pweight = weight_cons
svyset ea [pweight=pweight], strata(strata) singleunit(centered)

gen lcons_value = log(cons_value)
svy: mean lcons_value, over(remit12m)
lincom [lcons_value]Yes - [lcons_value]No

tabout remit12m using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean lcons_value se) h2(educ expenses by recipient status)  f(3) sebnone npos(col) append 

gen q_remit = 1 if quintiles_tc==1 & remit12m==1 
replace q_remit = 2 if quintiles_tc==1 & remit12m==0 
replace q_remit = 3 if quintiles_tc==2 & remit12m==1 
replace q_remit = 4 if quintiles_tc==2 & remit12m==0 
replace q_remit = 5 if quintiles_tc==3 & remit12m==1
replace q_remit = 6 if quintiles_tc==3 & remit12m==0
replace q_remit = 7 if quintiles_tc==4 & remit12m==1
replace q_remit = 8 if quintiles_tc==4 & remit12m==0
replace q_remit = 9 if quintiles_tc==5 & remit12m==1
replace q_remit = 10 if quintiles_tc==5 & remit12m==0
la def lq_remit 1 "Q1-recipient" 2 "Q1 non-recipient" 3 "Q2 recipient" 4 "Q2 non-recipient" 5 "Q3 recipient" 6 "Q3 non-recipient" 7 "Q4 recipient" 8 "Q4 non-recipient" 9 "Q5 recipient" 10 "Q5 non-recipient", replace 
la val q_remit lq_remit

svy: mean lcons_value, over(q_remit)
lincom [lcons_value]_subpop_1 - [lcons_value]_subpop_2
lincom [lcons_value]_subpop_3 - [lcons_value]_subpop_4
lincom [lcons_value]_subpop_5 - [lcons_value]_subpop_6
lincom [lcons_value]_subpop_7 - [lcons_value]_subpop_8
lincom [lcons_value]_subpop_9 - [lcons_value]_subpop_10

tabout q_remit using "${gsdOutput}/Raw_Data_1.xls", svy sum c(mean lcons_value se) h2(educ expenses by recipient status)  f(3) sebnone npos(col) append 


* Remittances and Consumption
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen assert(match master) keepusing(tc_core)
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)

* Means by breakdown
gen type_remit = 1 if type==1 & remit12m==1 
replace type_remit = 2 if type==1 & remit12m==0 
replace type_remit = 3 if type==2 & remit12m==1 
replace type_remit = 4 if type==2 & remit12m==0 
replace type_remit = 5 if type==3 & remit12m==1
replace type_remit = 6 if type==3 & remit12m==0
la def ltype_remit 1 "Urban-recipient" 2 "Urban non-recipient" 3 "Rural recipient" 4 "Rural non-recipient" 5 "IDP recipient" 6 "IDP non-recipient", replace 
la val type_remit ltype_remit

replace tc_imp_f = tc_imp_f / hhsize / 7
replace tc_imp_nf = tc_imp_nf / hhsize / 7
gen ltc_imp_f = log(tc_imp_f)
gen ltc_imp_nf = log(tc_imp_nf)
gen ltc_imp_d = log(tc_imp_d)
gen ltc_imp = log(tc_imp)

svy: mean ltc_imp, over(remit12m)
lincom [ltc_imp]No - [ltc_imp]Yes
svy: mean ltc_imp, over(type remit12m)
lincom [ltc_imp]_subpop_1 - [ltc_imp]_subpop_2
lincom [ltc_imp]_subpop_3 - [ltc_imp]_subpop_4
lincom [ltc_imp]_subpop_5 - [ltc_imp]_subpop_6
svy: mean ltc_imp_f, over(type remit12m)
lincom [ltc_imp_f]_subpop_1 - [ltc_imp_f]_subpop_2
lincom [ltc_imp_f]_subpop_3 - [ltc_imp_f]_subpop_4
lincom [ltc_imp_f]_subpop_5 - [ltc_imp_f]_subpop_6
svy: mean ltc_imp_nf, over(type remit12m)
lincom [ltc_imp_nf]_subpop_1 - [ltc_imp_nf]_subpop_2
lincom [ltc_imp_nf]_subpop_3 - [ltc_imp_nf]_subpop_4
lincom [ltc_imp_nf]_subpop_5 - [ltc_imp_nf]_subpop_6
svy: mean ltc_imp_d, over(type remit12m)
lincom [ltc_imp_d]_subpop_1 - [ltc_imp_d]_subpop_2
lincom [ltc_imp_d]_subpop_3 - [ltc_imp_d]_subpop_4
lincom [ltc_imp_d]_subpop_5 - [ltc_imp_d]_subpop_6

tabout type_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp se) f(3) npos(col) replace
tabout type_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp_f se) f(3) npos(col) append
tabout type_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp_nf se) f(3) npos(col) append
tabout type_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp_d se) f(3) npos(col) append


* Distributions
xtile cons_remit_pct = tc_imp [pweight=pweight] if remit12m==1 & type==1, n(10)
xtile cons_noremit_pct = tc_imp [pweight=pweight] if remit12m==0 & type==1, n(10)
tabout cons_remit_pct using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean tc_imp se) f(3) npos(col) h2(urban recipients) append
tabout cons_noremit_pct using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean tc_imp se) f(3) npos(col) h2(urban non-recipients) append

xtile cons_remit_pct_r = tc_imp [pweight=pweight] if remit12m==1 & type==2, n(10)
xtile cons_noremit_pct_r = tc_imp [pweight=pweight] if remit12m==0 & type==2, n(10)
tabout cons_remit_pct_r using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean tc_imp se) f(3) npos(col) h2(rural recipients) append
tabout cons_noremit_pct_r using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean tc_imp se) f(3) npos(col) h2(rural non recipients) append


* Hunger
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)
tabout hunger remit12m using "${gsdOutput}/Raw_Data_2.xls", svy percent c(col se) sebnone npos(col) h1(Remittances and hunger) append

* consumption by income quintile
svyset ea [pweight=pweight], strata(strata) singleunit(centered)
gen q_remit = 1 if quintiles_tc==1 & remit12m==1 
replace q_remit = 2 if quintiles_tc==1 & remit12m==0 
replace q_remit = 3 if quintiles_tc==2 & remit12m==1 
replace q_remit = 4 if quintiles_tc==2 & remit12m==0 
replace q_remit = 5 if quintiles_tc==3 & remit12m==1
replace q_remit = 6 if quintiles_tc==3 & remit12m==0
replace q_remit = 7 if quintiles_tc==4 & remit12m==1
replace q_remit = 8 if quintiles_tc==4 & remit12m==0
replace q_remit = 9 if quintiles_tc==5 & remit12m==1
replace q_remit = 10 if quintiles_tc==5 & remit12m==0

la def lq_remit 1 "Q1-recipient" 2 "Q1 non-recipient" 3 "Q2 recipient" 4 "Q2 non-recipient" 5 "Q3 recipient" 6 "Q3 non-recipient" 7 "Q4 recipient" 8 "Q4 non-recipient" 9 "Q5 recipient" 10 "Q5 non-recipient", replace 
la val q_remit lq_remit
tabout q_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp se) f(3) npos(col) append
tabout q_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp_f se) f(3) npos(col) append
tabout q_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp_nf se) f(3) npos(col) append
tabout q_remit using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean ltc_imp_d se) f(3) npos(col) append

svy: mean ltc_imp, over(q_remit)
lincom [ltc_imp]_subpop_1 - [ltc_imp]_subpop_2
lincom [ltc_imp]_subpop_3 - [ltc_imp]_subpop_4
lincom [ltc_imp]_subpop_5 - [ltc_imp]_subpop_6
lincom [ltc_imp]_subpop_7 - [ltc_imp]_subpop_8
lincom [ltc_imp]_subpop_9 - [ltc_imp]_subpop_10
svy: mean ltc_imp_f, over(q_remit)
lincom [ltc_imp_f]_subpop_1 - [ltc_imp_f]_subpop_2
lincom [ltc_imp_f]_subpop_3 - [ltc_imp_f]_subpop_4
lincom [ltc_imp_f]_subpop_5 - [ltc_imp_f]_subpop_6
lincom [ltc_imp_f]_subpop_7 - [ltc_imp_f]_subpop_8
lincom [ltc_imp_f]_subpop_9 - [ltc_imp_f]_subpop_10
svy: mean ltc_imp_nf, over(q_remit)
lincom [ltc_imp_nf]_subpop_1 - [ltc_imp_nf]_subpop_2
lincom [ltc_imp_nf]_subpop_3 - [ltc_imp_nf]_subpop_4
lincom [ltc_imp_nf]_subpop_5 - [ltc_imp_nf]_subpop_6
lincom [ltc_imp_nf]_subpop_7 - [ltc_imp_nf]_subpop_8
lincom [ltc_imp_nf]_subpop_9 - [ltc_imp_nf]_subpop_10
svy: mean ltc_imp_d, over(q_remit)
lincom [ltc_imp_d]_subpop_1 - [ltc_imp_d]_subpop_2
lincom [ltc_imp_d]_subpop_3 - [ltc_imp_d]_subpop_4
lincom [ltc_imp_d]_subpop_5 - [ltc_imp_d]_subpop_6
lincom [ltc_imp_d]_subpop_7 - [ltc_imp_d]_subpop_8
lincom [ltc_imp_d]_subpop_9 - [ltc_imp_d]_subpop_10

* Consumption value by income quintile
tabout quintiles_tc using "${gsdOutput}/Raw_Data_2.xls" , svy sum c(mean tc_imp se) f(3) npos(col) append

* Sources of income and remittances
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match) keepusing(ind_profile)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"
gen pweight = weight_cons * hhsize
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)

recode main_income_source (1=1) (2=2) (5=3) (7 8=4) (3 4 6 9 10 11 12 = 5), gen(inc)
la def linc 1 "Salaried labor" 2 "Remittances from abroad" 3 "Family assistance" 4 "Family business" 5 "Other", replace
la val inc linc 
tabout inc remit12m using "${gsdOutput}/Raw_Data_2.xls" , svy percent c(col se) npos(col) sebnone h1(Main source of income by remit status) append
tabout inc type using "${gsdOutput}/Raw_Data_2.xls", svy percent c(col se) npos(col) sebnone h1(Main source of income by remit status and type) append
tabout inc type using "${gsdOutput}/Raw_Data_2.xls" if remit12m==1, svy percent c(col se) npos(col) sebnone h1(Main source of income by remit status and type, remit==1) append
tabout inc type using "${gsdOutput}/Raw_Data_2.xls" if remit12m==0, svy percent c(col se) npos(col) sebnone h1(Main source of income by remit status and type, remit==0) append
tabout inc ind_profile using "${gsdOutput}/Raw_Data_2.xls", svy percent c(col se) npos(col) sebnone h1(Main source of income by regional breakdown) append
tabout inc quintiles_tc using "${gsdOutput}/Raw_Data_2.xls", svy percent c(col se) npos(col) sebnone h1(Main source of income by quintile breakdown) append

* Additional labour market statistics 
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(astrata hhh_gender quintiles_tc weight_cons poorPPP remit12m remit12m_usd type main_income_source) nogen
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
xtile quint_remit = remit12m_pc

svy: mean unemp_7d if lfp_7d==1, over(remit12m)
lincom [unemp_7d]No - [unemp_7d]Yes
svy: mean unemp_7d if lfp_7d==1 , over(ind_profile remit12m)
lincom [unemp_7d]_subpop_1 - [unemp_7d]_subpop_2
lincom [unemp_7d]_subpop_3 - [unemp_7d]_subpop_4
lincom [unemp_7d]_subpop_5 - [unemp_7d]_subpop_6
lincom [unemp_7d]_subpop_7 - [unemp_7d]_subpop_8
lincom [unemp_7d]_subpop_9 - [unemp_7d]_subpop_10
lincom [unemp_7d]_subpop_11 - [unemp_7d]_subpop_12

svy: mean lfp_7d, over(remit12m)
lincom [lfp_7d]No - [lfp_7d]Yes
svy: mean lfp_7d, over(ind_profile remit12m)
lincom [lfp_7d]_subpop_1 - [lfp_7d]_subpop_2
lincom [lfp_7d]_subpop_3 - [lfp_7d]_subpop_4
lincom [lfp_7d]_subpop_5 - [lfp_7d]_subpop_6
lincom [lfp_7d]_subpop_7 - [lfp_7d]_subpop_8
lincom [lfp_7d]_subpop_9 - [lfp_7d]_subpop_10
lincom [lfp_7d]_subpop_11 - [lfp_7d]_subpop_12

svy: mean emp_hrs, over(remit12m)
lincom [emp_hrs]No - [emp_hrs]Yes
svy: mean emp_hrs, over(ind_profile remit12m)
lincom [emp_hrs]_subpop_1 - [emp_hrs]_subpop_2
lincom [emp_hrs]_subpop_3 - [emp_hrs]_subpop_4
lincom [emp_hrs]_subpop_5 - [emp_hrs]_subpop_6
lincom [emp_hrs]_subpop_7 - [emp_hrs]_subpop_8
lincom [emp_hrs]_subpop_9 - [emp_hrs]_subpop_10
lincom [emp_hrs]_subpop_11 - [emp_hrs]_subpop_12

* Poverty without remittances
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen assert(match master) keepusing(tc_imp_nr poorPPP_nr_prob poorPPP_nr50_prob)
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)

qui tabout ind_profile using "${gsdOutput}/Raw_Data_2.xls" if remit12m==1, svy sum c(mean poorPPP_nr_prob se) f(3) sebnone npos(col) h2(Poverty without remittances I) append
qui tabout remit12m using "${gsdOutput}/Raw_Data_2.xls", svy sum c(mean poorPPP_nr_prob se) f(3) sebnone npos(col) h2(Poverty without remittances II) append
qui tabout ind_profile using "${gsdOutput}/Raw_Data_2.xls" if remit12m==1, svy sum c(mean poorPPP_nr50_prob se) f(3) sebnone npos(col) h2(Poverty without remittances, 50% I) append
qui tabout remit12m using "${gsdOutput}/Raw_Data_2.xls", svy sum c(mean poorPPP_nr50_prob se) f(3) sebnone npos(col) h2(Poverty without remittances, 50% II) append

svy: mean poorPPP_nr_prob, over(remit12m)
lincom [poorPPP_nr_prob]Yes - [poorPPP_nr_prob]No
svy: mean poorPPP_nr50_prob, over(remit12m)
lincom [poorPPP_nr50_prob]Yes - [poorPPP_nr50_prob]No


** ADDITIONAL STATS FOR REVISION ROUND ** 
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)

* Remittances value and poverty
gen remit12m_pc = remit12m_usd / hhsize 
xtile remit12m_pct = remit12m_pc [pw=pweight], n(20) 
svy: mean poorPPP, over(remit12m_pct)
svy: mean remit12m_pc, over(remit12m_pct)
svy: mean remit12m_pct, over(type)
svy: mean poorPPP if remit12m==1, over(type)
qui tabout remit12m_pct using "${gsdOutput}/Raw_Data_3.xls", svy sum c(mean poorPPP se) f(3) sebnone npos(col) h2(Poverty and amount of remittances) replace
qui tabout type using "${gsdOutput}/Raw_Data_3.xls" if remit12m==1, svy sum c(mean poorPPP se) f(3) sebnone npos(col) h2(Poverty and amount of remittances) append
qui tabout type using "${gsdOutput}/Raw_Data_3.xls" if remit12m==1, svy sum c(mean remit12m_pct se) f(3) sebnone npos(col) h2(Poverty and amount of remittances) append

**** Hunger and remittances ****
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)

* Experience of hunger
svy: reg hunger remit12m
svy: reg hunger remit12m_usd 
recode remit12m_usd (.=0)
svy: reg hunger remit12m_usd 

recode hunger (1=0) (2 3 4 = 1), gen(hunger_bin)
svy: reg hunger_bin remit12m
svy: mean hunger_bin, over(remit12m)

* No money to buy food
svy: mean nomoney, over(remit12m)
lincom [nomoney]Yes - [nomoney]No
qui tabout remit12m using "${gsdOutput}/Raw_Data_3.xls", svy sum c(mean nomoney se) f(3) sebnone npos(col) h2(no money for food by remit status) append

* Meals adults / children
recode meals_adult (0 1 = 0) (2/max = 1) if !mi(meals_adult), gen(m_a)
svy: reg meals_adult remit12m 
tabout m_a remit12m using "${gsdOutput}/Raw_Data_3.xls", svy percent c(col se) npos(col) sebnone h1(Meals Adults) append

recode meals_childrenu5 (0 1 = 0) (2/max = 1) if !mi(meals_childrenu5), gen(m_c)
svy: reg  meals_childrenu5 remit12m
tabout m_c remit12m using "${gsdOutput}/Raw_Data_3.xls", svy percent c(col se) npos(col) sebnone h1(Meals Children) append


* Remittances before and change 
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)

svy: tab remitmoreless if type==3
svy: tab remit12mbefore

tabout remitmoreless using "${gsdOutput}/Raw_Data_3.xls", svy percent c(col se) npos(col) sebnone h1(Change in remit value) append
tabout remitchange using "${gsdOutput}/Raw_Data_3.xls", svy percent c(col se) npos(col) sebnone h1(Reason for change in remit value) append
tabout remit12mbefore using "${gsdOutput}/Raw_Data_3.xls", svy percent c(col se) npos(col) sebnone h1(Remit previous year) append

* Effect on poverty
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)
svy: mean poorPPP, over(remitmoreless)
lincom [poorPPP]_subpop_1 - [poorPPP]_subpop_2
lincom [poorPPP]_subpop_1 - [poorPPP]_subpop_3
lincom [poorPPP]_subpop_2 - [poorPPP]_subpop_3
tabout remitmoreless using "${gsdOutput}/Raw_Data_3.xls", svy sum c(mean poorPPP  se) f(3) sebnone npos(col) h2(poverty by remit change) append

* Reasons for change in remittances
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)
tabout remitmoreless type using "${gsdOutput}/Raw_Data_3.xls", svy percent c(col se) npos(col) sebnone h1(Change in remit value) append

* Look at poverty gap
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"

gen idp = type==3
svy: mean pgi, over(remit12m)
svy: mean pgi, over(ind_profile remit12m)
svy: mean pgi if type==3, over(remit12m)
lincom [pgi]Yes - [pgi]No
svy: mean poorPPP if idp==1, over(remit12m)
lincom [poorPPP]Yes - [poorPPP]No

svy: mean pseverity if idp==1, over(remit12m)
lincom [pseverity]Yes - [pseverity]No

svy: mean pgi  if poorPPP==1, over(remit12m)

* Remittances as drivers of wealth vs. wealth as drivers of remittances 
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen assert(match master) keepusing(tc_core)
svy: mean tc_core, over(type)
lincom [tc_core]1 - [tc_core]2

svy: mean tc_core if remit12m==0, over(type)
lincom [tc_core]1 - [tc_core]2


* What's happening in IDP settlements? A look at the poverty gap and the daily pc value of remittances
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen remit12m_pc = remit12m_usd / hhsize 
la var remit12m_pc "Value of remittances pc, last 12m"
gen pweight = weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata) singleunit(centered)

* Povert gap relative to remittances value
gen pgap = (plinePPP - tc_imp) if !mi(tc_imp) & tc_imp < plinePPP
gen remit_pcpd = remit12m_pc / 365
gen remit_gap = remit_pcpd / pgap
svy: mean remit_gap, over(type)

* Remittances value between poor and nonpoor
svy: mean remit12m_pc, over(poorPPP type)

***************************************************************
** Special Issue: Sources of income - full list for appendix **
***************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
svyset ea [pweight=weight_adj], strata(strata) singleunit(centered)
tabout main_income_source ind_profile using "${gsdOutput}/Raw_Data_4.xls", svy percent c(col) npos(col) sebnone h1(Main Source of Income - Regional) replace

svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
tabout main_income_source quintiles_tc using "${gsdOutput}/Raw_Data_4.xls", svy percent c(col) npos(col) sebnone h1(Main Source of Income - Quintiles) append



*****************************
***  Integrate all files  ***
*****************************
insheet using "${gsdOutput}/Raw_Data_1.xls", clear nonames tab
export excel using "${gsdOutput}/Remittances_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_1")
erase "${gsdOutput}/Raw_Data_1.xls"

insheet using "${gsdOutput}/Raw_Data_2.xls", clear nonames tab
export excel using "${gsdOutput}/Remittances_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_2")
erase "${gsdOutput}/Raw_Data_2.xls"

insheet using "${gsdOutput}/Raw_Data_3.xls", clear nonames tab
export excel using "${gsdOutput}/Remittances_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_3")
erase "${gsdOutput}/Raw_Data_3.xls"

insheet using "${gsdOutput}/Raw_Data_4.xls", clear nonames tab
export excel using "${gsdOutput}/Remittances_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_4")
erase "${gsdOutput}/Raw_Data_4.xls"

