*Social protection analysis for the Somali Poverty Profile 2016

set more off
set seed 23061580 
set sortseed 17041585

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Perfect targeting: generate variables for the analysis
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen pop=hhsize*weight_cons if tc_imp!=.c
gen gap=pgi*pop
egen totwgap=sum(gap)
egen totpop=sum(pop)
gen w_avg_pgi=totwgap/totpop

gen transfer1=0
replace transfer1=w_avg_pgi*plinePPP if tc_imp<plinePPP
gen transfer2=0
replace transfer2=2*transfer1 if tc_imp<plinePPP

gen poorPPP_option1=poorPPP
replace poorPPP_option1 = 0 if tc_imp+transfer1>=plinePPP
gen poorPPP_option2=poorPPP
replace poorPPP_option2 = 0 if tc_imp+transfer2>=plinePPP

gen pgi_option1=0
replace pgi_option1 = (plinePPP - (tc_imp+transfer1))/plinePPP if (!mi(tc_imp) & (tc_imp+transfer1)<plinePPP)
gen pgi_option2=0
replace pgi_option2 = (plinePPP - (tc_imp+transfer2))/plinePPP if (!mi(tc_imp) & (tc_imp+transfer2)<plinePPP)

la var pgi_option1 "Poverty Gap Index, uniform transfer to all poor of avg poverty gap"
la var pgi_option2 "Poverty Gap Index, uniform transfer to all poor of twice avg poverty gap"


*Perfect targeting: extract key data
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
qui tabout type using "${gsdOutput}/Social_Protection_1.xls", svy sum c(mean poorPPP) sebnone f(3) h2(Poverty headcount) replace
qui tabout type using "${gsdOutput}/Social_Protection_1.xls", svy sum c(mean poorPPP_option1) sebnone f(3) h2(Poverty headcount with uniform transfer to all poor of poverty gap) append
qui tabout type using "${gsdOutput}/Social_Protection_1.xls", svy sum c(mean poorPPP_option2) sebnone f(3) h2(Poverty headcount with uniform transfer to all poor of twice the poverty gap) append
qui tabout type using "${gsdOutput}/Social_Protection_1.xls" if weight_cons<., svy sum c(mean pgi) sebnone f(3) h2(Poverty Depth) append
qui tabout type using "${gsdOutput}/Social_Protection_1.xls" if weight_cons<., svy sum c(mean pgi_option1) sebnone f(3) h2(Poverty Depth with uniform transfer to all poor of poverty gap) append
qui tabout type using "${gsdOutput}/Social_Protection_1.xls" if weight_cons<., svy sum c(mean pgi_option2) sebnone f(3) h2(Poverty Depth with uniform transfer to all poor of twice the poverty gap) append


*Perfect targeting: obtain the cost 
gen tot_annual_transfer1=transfer1*365*hhsize*weight_cons
gen tot_annual_transfer2=transfer2*365*hhsize*weight_cons
collapse (sum) tot_annual_transfer1 tot_annual_transfer2, by(type)
qui tabout type using "${gsdOutput}/Social_Protection_1.xls", sum c(mean tot_annual_transfer1) sebnone f(3) h2(Cost of perfect targeting - transfer 1) append
qui tabout type using "${gsdOutput}/Social_Protection_1.xls", sum c(mean tot_annual_transfer2) sebnone f(3) h2(Cost of perfect targeting - transfer 2) append


*Proxy Means Targeting: generate variables for the analysis
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen keep(match master) keepusing(tc_core)
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen wtc_imp=tc_imp*hhsize*weight_cons
gen wtc_cor=tc_core*hhsize*weight_cons
egen tot_tc_imp=sum(wtc_imp)
egen tot_tc_core=sum(wtc_cor)
gen w_avg_r=tot_tc_core/tot_tc_imp

gen plinePPP_core=w_avg_r*plinePPP
gen poor_core=.
replace poor_core=1 if tc_core<plinePPP_core & !missing(tc_core)
replace poor_core=0 if tc_core>=plinePPP_core & !missing(tc_core)

label var poor_core "Core consumption Below core-only 2011 PPP poverty line"
label define lpoor_core 0 "Non-poor" 1 "Poor"
label values poor_core lpoor_core


*Proxy Means Targeting: extract key data
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
qui tabout type using "${gsdOutput}/Social_Protection_2.xls", svy sum c(mean poorPPP) sebnone f(3) h2(Poverty headcount by type) replace
qui tabout type using "${gsdOutput}/Social_Protection_2.xls", svy sum c(mean poor_core) sebnone f(3) h2(Core consumption by type) append
qui tabout ind_profile using "${gsdOutput}/Social_Protection_2.xls", svy sum c(mean poorPPP) sebnone f(3) h2(Poverty headcount by region) append
qui tabout ind_profile using "${gsdOutput}/Social_Protection_2.xls", svy sum c(mean poor_core) sebnone f(3) h2(Core consumption by region) append

*Logit regression to obtain the score card
logit poor_core dependency_ratio i.hhh_gender hhsize i.emp_7d_hh i.hhh_edu i.floor_material i.house_ownership i.hunger i.house_type_cat i.team i.type i.ind_profile i.remit12m, robust
outreg2 using "${gsdOutput}/Social_Protection_ScoreCard.xls", bdec(3) tdec(3) rdec(3) nolabel ctitle(All households) replace
predict p
save "${gsdData}/1-CleanTemp/hh_PMT.dta", replace


*Determines threshold  for fitted values of poor_core. The threshold is determined to minimize type 1 + type 2 errors.
forvalues i = 0/100 {
	gen pfalse`i' = hhsize*weight_cons if ((poorPPP==0 & p>(`i'/100))& p!=.)
	gen nfalse`i' = hhsize*weight_cons if ((poorPPP==1 & p<=(`i'/100)) & p!=.)
	}

collapse (sum) pfalse* nfalse*

gen hid=1
order hid
reshape long pfalse nfalse, i(hid) j(threshold)
drop hid
gen tot_error= pfalse+nfalse
egen min_error=min(tot_error)
gen temp1 = threshold if min_error==tot_error
su temp1
local temp2 = `r(mean)'

use "${gsdData}/1-CleanTemp/hh_PMT.dta", clear
gen pop=hhsize*weight_cons if tc_imp!=.c
gen gap=pgi*pop
egen totwgap=sum(gap)
egen totpop=sum(pop)
gen w_avg_pgi=totwgap/totpop

gen threshold = `temp2'/100

gen transfer_PMT1=0
replace transfer_PMT1=w_avg_pgi*plinePPP if p>=threshold
gen transfer_PMT2=0
replace transfer_PMT2=2*w_avg_pgi*plinePPP if p>=threshold

gen poorPPP_PMT1=poorPPP
replace poorPPP_PMT1 = 0 if tc_imp+transfer_PMT1>=plinePPP
gen poorPPP_PMT2=poorPPP
replace poorPPP_PMT2 = 0 if tc_imp+transfer_PMT2>=plinePPP

gen pgi_PMT1=0
replace pgi_PMT1 = (plinePPP - (tc_imp+transfer_PMT1))/plinePPP if (!mi(tc_imp) & (tc_imp+transfer_PMT1)<plinePPP)
gen pgi_PMT2=0
replace pgi_PMT2 = (plinePPP - (tc_imp+transfer_PMT2))/plinePPP if (!mi(tc_imp) & (tc_imp+transfer_PMT2)<plinePPP)

la var pgi_PMT1 "Poverty Gap Index, PMT1"
la var pgi_PMT2 "Poverty Gap Index, PMT2"


*Proxy Means Targeting: extract key data
svyset ea [pweight=pweight], strata(strata)
qui tabout type using "${gsdOutput}/Social_Protection_3.xls", svy sum c(mean poorPPP) sebnone f(3) h2(Poverty headcount) replace
qui tabout type using "${gsdOutput}/Social_Protection_3.xls", svy sum c(mean poorPPP_PMT1) sebnone f(3) h2(Poverty headcount PMT1) append
qui tabout type using "${gsdOutput}/Social_Protection_3.xls", svy sum c(mean poorPPP_PMT2) sebnone f(3) h2(Poverty headcount PMT2) append
qui tabout type using "${gsdOutput}/Social_Protection_3.xls" if weight_cons<., svy sum c(mean pgi) sebnone f(3) h2(Poverty Depth) append
qui tabout type using "${gsdOutput}/Social_Protection_3.xls" if weight_cons<., svy sum c(mean pgi_PMT1) sebnone f(3) h2(Poverty Depth PMT1) append
qui tabout type using "${gsdOutput}/Social_Protection_3.xls" if weight_cons<., svy sum c(mean pgi_PMT2) sebnone f(3) h2(Poverty Depth PMT2) append


*Cost, Coverage, Leakage
gen tot_annual_transfer_PMT1=transfer_PMT1*365*hhsize*weight_cons
gen tot_annual_transfer_PMT2=transfer_PMT2*365*hhsize*weight_cons
gen tot_targeted =hhsize*weight_cons_extra if (p>threshold & p!=.)
gen tot_poor=hhsize*weight_cons_extra if poorPPP==1
gen tot_pop=hhsize*weight_cons_extra
gen tot_targeted_poor=hhsize*weight_cons_extra if (poorPPP==1 & p>threshold & p!=.)
gen tot_targeted_npoor=hhsize*weight_cons_extra if (poorPPP==0 & p>threshold & p!=.)
gen tot_ntargeted_poor=hhsize*weight_cons_extra if (poorPPP==1 & p<=threshold & p!=.)
gen tot_ntargeted_npoor=hhsize*weight_cons_extra if (poorPPP==0 & p<=threshold & p!=.)
gen tot_ntargeted_sc_poor=hhsize*weight_cons_extra if (poorPPP==1 & p==.)
gen tot_ntargeted_sc_npoor=hhsize*weight_cons_extra if (poorPPP==0 & p==.)
*gen tot_leakage=hhsize*weight_cons if (poorPPP==0 & p>=threshold & p!=.)
collapse (sum) tot_annual_transfer_PMT1 tot_annual_transfer_PMT2 tot_targeted tot_poor tot_pop tot_targeted_poor tot_targeted_npoor tot_ntargeted_poor tot_ntargeted_npoor tot_ntargeted_sc_poor tot_ntargeted_sc_npoor, by(type)


*Perfect targeting: obtain the cost 
qui tabout type using "${gsdOutput}/Social_Protection_4.xls", sum c(mean tot_annual_transfer_PMT1) sebnone f(3) h2(Cost of tot_annual_transfer_PMT1 by type) replace
qui foreach var of varlist tot_annual_transfer_PMT2-tot_ntargeted_sc_npoor {
	tabout type using "${gsdOutput}/Social_Protection_4.xls", sum c(mean `var') sebnone f(3) h2(Cost of `var' by type) append
}


*Simulate combinations of poverty and cost, based on different transfer amounts for PT and PMT
qui tabout type using "${gsdOutput}/Social_Protection_5.xls", sum c(mean tot_annual_transfer_PMT1) sebnone f(3) h2(Create the spreadsheet for all the simulation) replace
qui foreach x in 0.5 0.6 0.7 0.8 0.9 1.0 1.1 1.2 1.3 1.4 1.5 1.6 1.7 1.8 1.9 2.0 2.1 2.2 2.3 2.4 2.5 {
	*Perfect targeting: generate variables for the analysis
	use "${gsdData}/1-CleanOutput/hh.dta", clear
	gen pop=hhsize*weight_cons if tc_imp!=.c
	gen gap=pgi*pop
	egen totwgap=sum(gap)
	egen totpop=sum(pop)
	gen w_avg_pgi=totwgap/totpop
	gen transfer1=0
	replace transfer1=`x'*w_avg_pgi*plinePPP if tc_imp<plinePPP
	gen poorPPP_option1=poorPPP
	replace poorPPP_option1 = 0 if tc_imp+transfer1>=plinePPP

	*Perfect targeting: extract key data
	gen pweight = weight_cons * hhsize
	svyset ea [pweight=pweight], strata(strata)
	qui tabout type using "${gsdOutput}/Social_Protection_5.xls", svy sum c(mean poorPPP_option1) sebnone f(3) h2(Poverty headcount with uniform transfer to all poor of poverty gap `x') append

	*Perfect targeting: obtain the cost 
	gen tot_annual_transfer1=transfer1*365*hhsize*weight_cons
	collapse (sum) tot_annual_transfer1, by(type)
	qui tabout type using "${gsdOutput}/Social_Protection_5.xls", sum c(mean tot_annual_transfer1) sebnone f(3) h2(Cost of perfect targeting - transfer `x') append

	*Proxy Means Targeting: generate variables for the analysis
	use "${gsdData}/1-CleanOutput/hh.dta", clear
	merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen keep(match master) keepusing(tc_core)
	merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
	gen wtc_imp=tc_imp*hhsize*weight_cons
	gen wtc_cor=tc_core*hhsize*weight_cons
	egen tot_tc_imp=sum(wtc_imp)
	egen tot_tc_core=sum(wtc_cor)
	gen w_avg_r=tot_tc_core/tot_tc_imp
	gen plinePPP_core=w_avg_r*plinePPP
	gen poor_core=.
	replace poor_core=1 if tc_core<plinePPP_core & !missing(tc_core)
	replace poor_core=0 if tc_core>=plinePPP_core & !missing(tc_core)

	*Proxy Means Targeting: extract key data
	use "${gsdData}/1-CleanTemp/hh_PMT.dta", clear
	gen pop=hhsize*weight_cons if tc_imp!=.c
	gen gap=pgi*pop
	egen totwgap=sum(gap)
	egen totpop=sum(pop)
	gen w_avg_pgi=totwgap/totpop
	gen threshold = `temp2'/100
	*gen threshold = 41/100
	gen transfer_PMT1=0
	replace transfer_PMT1=`x'*w_avg_pgi*plinePPP if p>=threshold
	gen poorPPP_PMT1=poorPPP
	replace poorPPP_PMT1 = 0 if tc_imp+transfer_PMT1>=plinePPP

	*Proxy Means Targeting: extract key data
	svyset ea [pweight=pweight], strata(strata)
	qui tabout type using "${gsdOutput}/Social_Protection_5.xls", svy sum c(mean poorPPP_PMT1) sebnone f(3) h2(Poverty headcount PMT `x') append
    gen tot_annual_transfer_PMT1=transfer_PMT1*365*hhsize*weight_cons
	collapse (sum) tot_annual_transfer_PMT1, by(type)
	qui tabout type using "${gsdOutput}/Social_Protection_5.xls", sum c(mean tot_annual_transfer_PMT1) sebnone f(3) h2(Cost of tot_annual_transfer_PMT `x') append

}


*Integrate all files  
* Put all created sheets into one excel document
foreach i of numlist 1/5 {
	insheet using "${gsdOutput}/Social_Protection_`i'.xls", clear nonames tab
	export excel using "${gsdOutput}/SocialProtection_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_`i'") 
	erase "${gsdOutput}/Social_Protection_`i'.xls"
}
import delimited "${gsdOutput}/Social_Protection_ScoreCard.txt", varnames(nonames) clear 
export excel using "${gsdOutput}/SocialProtection_Figures_Final.xlsx", sheetreplace sheet("Raw_Logit") 
erase "${gsdOutput}/Social_Protection_ScoreCard.txt"
erase "${gsdOutput}/Social_Protection_ScoreCard.xls"
